==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/mots/lang/mots_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Dôležitá skupina:</b> Veľmi sa odporúča vybrať kľúčové slovo z tejto skupiny.',
	'avis_doublon_mot_cle' => 'Kľúčové slovo s týmto názvom už existuje. Naozaj chcete vytvoriť ďalšie?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administrátori stránky',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redaktori',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'návštevníci verejnej stránky, keď pošlú príspevok do diskusného fóra.',

	// C
	'creer_et_associer_un_mot' => 'Vytvoriť a pripojiť kľúčové slovo',

	// I
	'icone_creation_groupe_mots' => 'Vytvoriť novú skupinu klúčových slov',
	'icone_creation_mots_cles' => 'Vytvoriť nové kľúčové slovo',
	'icone_modif_groupe_mots' => 'Upraviť túto skupinu kľúčových slov',
	'icone_modifier_mot' => 'Upraviť toto kľúčové slovo',
	'icone_mots_cles' => 'Kľúčové slová',
	'icone_supprimer_groupe_mots' => 'Zmazať túto skupinu',
	'icone_voir_groupe_mots' => 'Zobraziť skupinu kľúčových slov',
	'icone_voir_tous_mots_cles' => 'Zobraziť všetky kľúčové slová',
	'info_1_groupe_mots' => '1 skupina kľúčových slov',
	'info_articles_lies_mot' => 'Články s týmto kľúčovým slovom',
	'info_aucun_groupe_mots' => 'Žiadna skupina kľúčových slov',
	'info_aucun_mot_cle' => 'Žiadne kľúčové slová',
	'info_changer_nom_groupe' => 'Zmeniť názov tejto skupiny:',
	'info_creation_mots_cles' => 'Tu vytvorte a nastavte kľúčové slová stránky',
	'info_dans_groupe' => 'V skupine:',
	'info_delet_mots_cles' => 'Požiadali ste o odstránené kľúčového slova <b>@titre_mot@</b> (@type_mot@). Toto kľúčové slovo je prepojené s <b>@texte_lie@;</b> toto rozhodnutie musíte potvrdiť:',
	'info_groupe_important' => 'Dôležitá skupina',
	'info_modifier_mot' => 'Upraviť kľúčové slovo:',
	'info_mots_cles' => 'Kľúčové slová',
	'info_mots_cles_association' => 'Kľúčové slová v tejto skupine možno priradiť:',
	'info_nb_groupe_mots' => '@nb@ skupín kľúčových slov',
	'info_oui_suppression_mot_cle' => 'Toto kľúčové slovo chcem odstrániť natrvalo.',
	'info_question_mots_cles' => 'Chcete na svojej stránke používať kľúčové slová?',
	'info_qui_attribue_mot_cle' => 'Kľúčové slová v tejto skupine môže priradiť:',
	'info_remplacer_mot' => 'Nahradiť "@titre@"',
	'info_retirer_mot' => 'Odstrániť toto kľúčové slovo',
	'info_retirer_mots' => 'Odstrániť všetky kľúčové slová',
	'info_rubriques_liees_mot' => 'Rubriky s týmto kľúčovým slovom',
	'info_selection_un_seul_mot_cle' => 'Z tejto skupiny nemôžete vybrať <b>len</b> toto jedno kľúčové slovo.',
	'info_supprimer_mot' => 'Odstrániť toto kľúčové slovo',
	'info_titre_mot_cle' => 'Názov kľúčového slova',
	'info_un_mot' => 'Naraz jedno kľúčové slovo',
	'item_ajout_mots_cles' => 'Povoliť používanie kľúčových slov v diskusných fórach',
	'item_non_ajout_mots_cles' => 'Nepovoliť používanie kľúčových slov v diskusných fórach',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nepoužívať rozšírené nastavenia skupín kľúčových slov',
	'item_non_utiliser_mots_cles' => 'Nepoužívať kľúčové slová',
	'item_utiliser_config_groupe_mots_cles' => 'Používať rozšírené nastavenia skupín kľúčových slov',
	'item_utiliser_mots_cles' => 'Používať kľúčové slová',

	// L
	'lien_ajouter_mot' => 'Pridať toto kľúčové slovo',
	'logo_groupe' => 'LOGO TEJTO SKUPINY',
	'logo_mot_cle' => 'LOGO KĽÚČOVÉHO SLOVA',

	// T
	'texte_config_groupe_mots_cles' => 'Chcete aktivovať podrobné nastavenia kľúčových slov, napr. určenie, či sa môže použiť jediné slovo zo skupiny, či je skupina dôležitá, atď.?',
	'texte_mots_cles' => 'Kľúčové slová vám umožňujú vytvárať tematické  prepojenia medzi článkami
  bez ohľadu na rubriku. Môžete to využiť na
  zlepšenie orientácie na stránke alebo dokonca ako nástroj
 na prispôsobenie vzhľadu stránky v šablóne.',
	'texte_mots_cles_dans_forum' => 'Chcete povoliť návštevníkom vyberať kľúčové slová vo verejných diskusných fórach? (Upozornenie: táto možnosť sa ťažko používa správne)',
	'texte_nouveau_mot' => 'Nové kľúčové slovo',
	'titre_config_groupe_mots_cles' => 'Nastavenie skupín kľúčových slov',
	'titre_gauche_mots_edit' => 'KĽÚČOVÉ SLOVO ČÍSLO:',
	'titre_groupe_mots' => 'Skupina kľúčových slov',
	'titre_groupe_mots_numero' => 'SKUPINA KĽÚČOVÝCH SLOV ČÍSLO:',
	'titre_groupes_mots' => 'Skupiny kľúčových slov',
	'titre_mots_cles_dans_forum' => 'Kľúčové slová v diskusných fórach na verejnej stránke',
	'titre_mots_tous' => 'Kľúčové slová',
	'titre_nouveau_groupe' => 'Nová skupina',
	'titre_objets_lies_mot' => 'Prepojené s týmto kľúčovým slovom:',
	'titre_page_mots_tous' => 'Kľúčové slová'
);

?>

==> spip_3.0.9.orig.tar.xz: spip-3.0.9.orig/plugins-dist/mots/lang/mots_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Dôležitá skupina:</b> Veľmi sa odporúča vybrať kľúčové slovo z tejto skupiny.',
	'avis_doublon_mot_cle' => 'Kľúčové slovo s týmto názvom už existuje. Naozaj chcete vytvoriť ďalšie?', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administrátori stránky',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redaktori',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'návštevníci verejnej stránky, keď pošlú príspevok do diskusného fóra.',

	// C
	'creer_et_associer_un_mot' => 'Vytvoriť a pripojiť kľúčové slovo',

	// I
	'icone_creation_groupe_mots' => 'Vytvoriť novú skupinu klúčových slov',
	'icone_creation_mots_cles' => 'Vytvoriť nové kľúčové slovo',
	'icone_modif_groupe_mots' => 'Upraviť túto skupinu kľúčových slov',
	'icone_modifier_mot' => 'Upraviť toto kľúčové slovo',
	'icone_mots_cles' => 'Kľúčové slová',
	'icone_supprimer_groupe_mots' => 'Zmazať túto skupinu',
	'icone_voir_groupe_mots' => 'Zobraziť skupinu kľúčových slov',
	'icone_voir_tous_mots_cles' => 'Zobraziť všetky kľúčové slová',
	'info_1_groupe_mots' => '1 skupina kľúčových slov',
	'info_articles_lies_mot' => 'Články s týmto kľúčovým slovom',
	'info_aucun_groupe_mots' => 'Žiadna skupina kľúčových slov',
	'info_aucun_mot_cle' => 'Žiadne kľúčové slová',
	'info_changer_nom_groupe' => 'Zmeniť názov tejto skupiny:',
	'info_creation_mots_cles' => 'Tu vytvorte a nastavte kľúčové slová stránky',
	'info_dans_groupe' => 'V skupine:',
	'info_delet_mots_cles' => 'Požiadali ste o odstránené kľúčového slova <b>@titre_mot@</b> (@type_mot@). Toto kľúčové slovo je prepojené s <b>@texte_lie@;</b> toto rozhodnutie musíte potvrdiť:',
	'info_groupe_important' => 'Dôležitá skupina',
	'info_modifier_mot' => 'Upraviť kľúčové slovo:',
	'info_mots_cles' => 'Kľúčové slová',
	'info_mots_cles_association' => 'Kľúčové slová v tejto skupine možno priradiť:',
	'info_nb_groupe_mots' => '@nb@ skupín kľúčových slov',
	'info_oui_suppression_mot_cle' => 'Toto kľúčové slovo chcem odstrániť natrvalo.',
	'info_question_mots_cles' => 'Chcete na svojej stránke používať kľúčové slová?',
	'info_qui_attribue_mot_cle' => 'Kľúčové slová v tejto skupine môže priradiť:',
	'info_remplacer_mot' => 'Nahradiť "@titre@"',
	'info_retirer_mot' => 'Odstrániť toto kľúčové slovo',
	'info_retirer_mots' => 'Odstrániť všetky kľúčové slová',
	'info_rubriques_liees_mot' => 'Rubriky s týmto kľúčovým slovom',
	'info_selection_un_seul_mot_cle' => 'Z tejto skupiny nemôžete vybrať <b>len</b> toto jedno kľúčové slovo.',
	'info_supprimer_mot' => 'Odstrániť toto kľúčové slovo',
	'info_titre_mot_cle' => 'Názov kľúčového slova',
	'info_un_mot' => 'Naraz jedno kľúčové slovo',
	'item_ajout_mots_cles' => 'Povoliť používanie kľúčových slov v diskusných fórach',
	'item_non_ajout_mots_cles' => 'Nepovoliť používanie kľúčových slov v diskusných fórach',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nepoužívať rozšírené nastavenia skupín kľúčových slov',
	'item_non_utiliser_mots_cles' => 'Nepoužívať kľúčové slová',
	'item_utiliser_config_groupe_mots_cles' => 'Používať rozšírené nastavenia skupín kľúčových slov',
	'item_utiliser_mots_cles' => 'Používať kľúčové slová',

	// L
	'lien_ajouter_mot' => 'Pridať toto kľúčové slovo',
	'logo_groupe' => 'LOGO TEJTO SKUPINY',
	'logo_mot_cle' => 'LOGO KĽÚČOVÉHO SLOVA',

	// T
	'texte_config_groupe_mots_cles' => 'Chcete aktivovať podrobné nastavenia kľúčových slov, napr. určenie, či sa môže použiť jediné slovo zo skupiny, či je skupina dôležitá, atď.?',
	'texte_mots_cles' => 'Kľúčové slová vám umožňujú vytvárať tematické  prepojenia medzi článkami
  bez ohľadu na rubriku. Môžete to využiť na
  zlepšenie orientácie na stránke alebo dokonca ako nástroj
 na prispôsobenie vzhľadu stránky v šablóne.',
	'texte_mots_cles_dans_forum' => 'Chcete povoliť návštevníkom vyberať kľúčové slová vo verejných diskusných fórach? (Upozornenie: táto možnosť sa ťažko používa správne)',
	'texte_nouveau_mot' => 'Nové kľúčové slovo',
	'titre_config_groupe_mots_cles' => 'Nastavenie skupín kľúčových slov',
	'titre_gauche_mots_edit' => 'KĽÚČOVÉ SLOVO ČÍSLO:',
	'titre_groupe_mots' => 'Skupina kľúčových slov',
	'titre_groupe_mots_numero' => 'SKUPINA KĽÚČOVÝCH SLOV ČÍSLO:',
	'titre_groupes_mots' => 'Skupiny kľúčových slov',
	'titre_mots_cles_dans_forum' => 'Kľúčové slová v diskusných fórach na verejnej stránke',
	'titre_mots_tous' => 'Kľúčové slová',
	'titre_nouveau_groupe' => 'Nová skupina',
	'titre_objets_lies_mot' => 'Prepojené s týmto kľúčovým slovom:',
	'titre_page_mots_tous' => 'Kľúčové slová'
);

?>
